@@ -2,8 +2,6 @@ import os
 import json
 import shutil
 import logging
-import importlib
-import pickle
 import numpy as np
 import pandas as pd
 from os.path import join, exists, split, dirname
@@ -11,24 +9,33 @@ from d3m.container import Dataset
 from d3m.utils import fix_uri
 from d3m.container.utils import save_container
 from d3m.metadata.problem import PerformanceMetricBase, TaskKeywordBase
-from d3m_interface.pipeline import PipelineParameter, PipelineConnection, PipelineModule
 
 logger = logging.getLogger(__name__)
 DATASET_ID = 'internal_dataset'
 
 
-def is_d3m_format(dataset, suffix):
-    if isinstance(dataset, str) and exists(join(dataset, 'dataset_%s/datasetDoc.json' % suffix)):
+def is_d3m_format(dataset_path, suffix):
+    if isinstance(dataset_path, str) and exists(join(dataset_path, 'dataset_%s' % suffix, 'datasetDoc.json')):
         return True
 
     return False
 
 
-def dataset_to_d3m(dataset_uri, output_folder, problem_config, suffix):
+def is_d3m_collection(dataset_path, collection_type):
+    with open(dataset_path) as fin:
+        dataset_doc = json.load(fin)
+        for data_resource in dataset_doc['dataResources']:
+            if data_resource.get('isCollection', False):
+                if data_resource['resType'] == collection_type:
+                    return True
+    return False
+
+
+def dataset_to_d3m(dataset_path, output_folder, problem_config, suffix):
     problem_config = check_problem_config(problem_config)
     dataset_folder = join(output_folder, 'temp', 'dataset_d3mformat', suffix, 'dataset_%s' % suffix)
     problem_folder = join(output_folder, 'temp', 'dataset_d3mformat', suffix, 'problem_%s' % suffix)
-    dataset = create_d3m_dataset(dataset_uri, dataset_folder)
+    dataset = create_d3m_dataset(dataset_path, dataset_folder)
     create_d3m_problem(dataset['learningData'], problem_folder, problem_config)
 
     return join(output_folder, 'temp', 'dataset_d3mformat', suffix)
@@ -66,13 +73,13 @@ def check_problem_config(problem_config):
     return problem_config
 
 
-def create_d3m_dataset(dataset_uri, destination_path):
-    if callable(dataset_uri):
-        dataset_uri = 'sklearn://' + dataset_uri.__name__.replace('load_', '')
+def create_d3m_dataset(dataset_path, destination_path):
+    if callable(dataset_path):
+        dataset_path = 'sklearn://' + dataset_path.__name__.replace('load_', '')
     if exists(destination_path):
         shutil.rmtree(destination_path)
 
-    dataset = Dataset.load(fix_uri(dataset_uri), dataset_id=DATASET_ID)
+    dataset = Dataset.load(fix_uri(dataset_path), dataset_id=DATASET_ID)
     save_container(dataset, destination_path)
 
     return dataset
@@ -148,10 +155,11 @@ def create_artificial_d3mtest(train_path, artificial_test_path, new_instances, t
     for i in range(len(new_instances)):
         text_value = new_instances[i]
         if need_media_folder:
-            file_path = join(media_folder, str(i) + '.txt')
+            file_name = str(i) + '.txt'
+            file_path = join(media_folder, file_name)
             with open(file_path, 'w') as fin:
                 fin.write(text_value)
-            text_value = file_path
+            text_value = file_name
 
         data['d3mIndex'].append(i)
         data[text_column].append(text_value)
@@ -163,9 +171,9 @@ def create_artificial_d3mtest(train_path, artificial_test_path, new_instances, t
 
 
 def d3mtext_to_dataframe(folder_path, text_column):
-    suffix = split(folder_path)[1]
-    dataframe = pd.read_csv(join(folder_path, 'dataset_%s/tables/learningData.csv' % suffix))
-    folder_files = join(folder_path, 'dataset_%s/media/' % suffix)
+    suffix = split(folder_path)[-1]
+    dataframe = pd.read_csv(join(folder_path, 'dataset_%s' % suffix, 'tables', 'learningData.csv'))
+    folder_files = join(folder_path, 'dataset_%s' % suffix, 'media')
 
     def read_text(file_name):
         file_path = join(folder_files, file_name)
@@ -178,45 +186,6 @@ def d3mtext_to_dataframe(folder_path, text_column):
     return dataframe
 
 
-def copy_folder(source_path, destination_path):
-    if exists(destination_path):
-        shutil.rmtree(destination_path)
-
-    shutil.copytree(source_path, destination_path)
-
-
-def make_pipeline_module(pipeline, name, package='d3m', version='2019.10.10'):
-    pipeline_module = PipelineModule(package=package, version=version, name=name)
-    pipeline.add_module(pipeline_module)
-    return pipeline_module
-
-
-def make_data_module(pipeline):
-    input_data = make_pipeline_module(pipeline, 'dataset', 'data', '0.0')
-    return input_data
-
-
-def connect(pipeline, from_module, to_module, from_output='produce', to_input='inputs'):
-    connection = PipelineConnection(from_module_id=from_module.id,
-                                    from_output_name=from_output,
-                                    to_module_id=to_module.id,
-                                    to_input_name=to_input)
-    pipeline.add_connection(connection)
-    to_module.add_connection_to(connection)
-
-
-def set_hyperparams(pipeline, module, **hyperparams):
-    parameters = PipelineParameter(module_id=module.id,
-                                   name='hyperparams',
-                                   value=pickle.dumps(hyperparams))
-    pipeline.add_parameters(parameters)
-
-
-def get_class(name):
-    package, classname = name.rsplit('.', 1)
-    return getattr(importlib.import_module(package), classname)
-
-
 def _add_step(steps, modules, params, module_to_step, mod):
     if mod.id in module_to_step:
         return module_to_step[mod.id]
@@ -246,14 +215,14 @@ def _add_step(steps, modules, params, module_to_step, mod):
                     inputs[conn.to_input_name].append('%s.%s' % (step, conn.from_output_name))
             else:
                 inputs[conn.to_input_name] = '%s.%s' % (step, conn.from_output_name)
-    #TODO load metadata from primitives
+    # TODO load metadata from primitives
     primitive_desc = {
         'id': mod.id,
         'version': mod.version,
         'python_path': mod.name,
         'name': mod.name
     }
-    with open(join(dirname(__file__), 'resource/primitives_metadata.json')) as f:
+    with open(join(dirname(__file__), 'resource', 'primitives_metadata.json')) as f:
         primitives_metadata = json.load(f)
         for primitve in primitives_metadata:
             if primitive_desc['python_path'] == primitve['python_path']:
