@@ -22,13 +22,13 @@ def plot_comparison_pipelines(pipelines):
     PipelineProfiler.plot_pipeline_matrix(pipelines)
 
 
-def plot_text_summary(dataset, text_column, label_column, positive_label, negative_label):
-    VisualTextAnalyzer.plot_text_summary(dataset, text_column=text_column, category_column=label_column,
-                                         positive_label=positive_label, negative_label=negative_label)
+def plot_text_summary(words_entities):
+    VisualTextAnalyzer.plot_text_summary(words_entities=words_entities)
 
 
 def plot_text_explanation(automl, train_path, artificial_test_path, model_id, instance_text, text_column, label_column, num_features, top_labels):
     train_data = pd.read_csv(join(train_path, 'dataset_TRAIN', 'tables', 'learningData.csv'))
+    train_data = train_data[train_data[label_column].notna()]  # Remove NaN values
     class_label_encoder = LabelEncoder()
     numerical_labels = class_label_encoder.fit_transform(train_data[label_column])
     class_one_hot_encoder = OneHotEncoder(sparse=False, categories='auto')
@@ -39,6 +39,7 @@ def plot_text_explanation(automl, train_path, artificial_test_path, model_id, in
         # Computing prediction probabilities
         create_artificial_d3mtest(train_path, artificial_test_path, instance_text_list, label_column, text_column)
         probabilities = automl.test(model_id, artificial_test_path, calculate_confidence=True)
+        probabilities = probabilities[probabilities[label_column].notna()]  # Remove NaN values
         probabilities = probabilities.pivot(index='d3mIndex', columns=label_column, values='confidence')
         probabilities = probabilities.values
 
@@ -48,3 +49,8 @@ def plot_text_explanation(automl, train_path, artificial_test_path, model_id, in
         explanation = explainer.explain_instance(instance_text, predict_proba, num_features=num_features, top_labels=top_labels)
     explanation.show_in_notebook()
 
+
+def get_words_entities(dataset, text_column, label_column, positive_label, negative_label):
+    processed_data = VisualTextAnalyzer.get_words_entities(dataset, category_column=label_column, text_column=text_column,
+                                                           positive_label=positive_label, negative_label=negative_label)
+    return processed_data
